@@ -1,13 +1,14 @@
 package App::CreateAcmeCPANListsImportModules;
 
-our $DATE = '2016-02-21'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-07-19'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Log::Any::IfLOG '$log';
+use Perinci::Sub::Util qw(err);
 
 our %SPEC;
 
@@ -42,6 +43,18 @@ _
         dist_dir => {
             schema => 'str*',
         },
+        exclude_unindexed => {
+            summary => 'Consult local CPAN index and exclude module entries '.
+                'that are not indexed on CPAN',
+            schema => 'bool',
+            default => 1,
+            description => <<'_',
+
+This requires `App::lcpan` to be installed and a local CPAN index to exist and
+be fairly recent.
+
+_
+        },
     },
 };
 sub create_acme_cpanlists_import_modules {
@@ -93,6 +106,30 @@ sub create_acme_cpanlists_import_modules {
             html => $content, %{ $mod->{extract_opts} // {}});
 
         $log->debugf("Extracted module names: %s", $mods);
+
+        if ($args{exclude_unindexed} && @$mods) {
+            require App::lcpan::Call;
+            my $lcpan_res = App::lcpan::Call::call_lcpan_script(
+                argv => [qw/mods -x --or/, @$mods],
+            );
+            return err("Can't list modules in lcpan", $lcpan_res)
+                unless $lcpan_res->[0] == 200;
+            my @excluded_mods;
+            my @included_mods;
+            for my $mod (@$mods) {
+                if (grep { $mod eq $_ } @{$lcpan_res->[2]}) {
+                    push @included_mods, $mod;
+                } else {
+                    push @excluded_mods, $mod;
+                }
+            }
+            $mods = \@included_mods;
+            if (@excluded_mods) {
+                $log->debugf("Excluded module names (not indexed on ".
+                                 "local CPAN mirror): %s", \@excluded_mods);
+            }
+        }
+
         return [412, "No module names found for $mod->{name}"] unless @$mods;
 
         my $module_path = "$dist_dir/lib/$namespace_pm/$mod->{name}.pm";
@@ -143,7 +180,7 @@ App::CreateAcmeCPANListsImportModules - Create Acme::CPANLists::Import::* module
 
 =head1 VERSION
 
-This document describes version 0.03 of App::CreateAcmeCPANListsImportModules (from Perl distribution App-CreateAcmeCPANListsImportModules), released on 2016-02-21.
+This document describes version 0.04 of App::CreateAcmeCPANListsImportModules (from Perl distribution App-CreateAcmeCPANListsImportModules), released on 2016-07-19.
 
 =head1 FUNCTIONS
 
@@ -157,7 +194,7 @@ An C<Acme::CPANLists::Import::*> module contains a module list where its entries
 to have a POD mentioning the modules, thus adding/improving to the POD "mentions
 cloud" on CPAN.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -167,6 +204,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<dist_dir> => I<str>
 
+=item * B<exclude_unindexed> => I<bool> (default: 1)
+
+Consult local CPAN index and exclude module entries that are not indexed on CPAN.
+
+This requires C<App::lcpan> to be installed and a local CPAN index to exist and
+be fairly recent.
+
 =item * B<modules>* => I<array[hash]>
 
 =item * B<namespace>* => I<str>
